# DesignFactors

Design Factor F: [ASME B31.8 vs ASME B31.4](https://whatispiping.com/differences-between-asme-b31-4-and-asme-b31-8/)

## ASME B31.4-2016

The Maximum Value of Design Factor F in thickness calculation following ASME B31.4 is 0.72. Lower values can be used as service and location may dictate.

-   Chapter IX Pipeline: 0.72
-   Chapter IX Platform Piping: 0.60
-   Chapter IX Risers: 0.60

## ASME B31.8-2016

Depending on the location class, the value of F in code ASME B31.8 varies from 0.4 to 0.8

-   Chapter VIII Pipeline: 0.72
-   Chapter VIII Platform Piping: 0.50
-   Chapter VIII Risers: 0.50
